@@ -20,6 +20,7 @@ from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.utils.files import FilesError
 from calculate.desktop.desktop import DesktopError
 from calculate.client.client import ClientError
+from calculate.lib.utils.samba import SambaError
 from calculate.lib.cl_template import TemplatesError
 
 _ = lambda x: x
@@ -32,7 +33,8 @@ class ClClientAction(Action):
     Ввести машину в домен или вывести
     """
     # ошибки, которые отображаются без подробностей
-    native_error = (FilesError, ClientError, DesktopError, TemplatesError)
+    native_error = (FilesError, ClientError, DesktopError, TemplatesError,
+                    SambaError)
 
     successMessage = None
     failedMessage = None
